<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-porte_plume?lang_cible=pt_br
// ** ne pas modifier le fichier **

return [

	// P
	'porte_plume_description' => 'Porte plume é uma barra de feramentas para SPIP que utiliza a biblioteca javascript [MarkItUp->http://markitup.jaysalvat.com/home/]',
	'porte_plume_nom' => 'Porte plume',
	'porte_plume_slogan' => 'Barre de ferramentas para edição de texto',
];
